@@ -19,7 +19,7 @@ _CLUSTERING_OPTIMIZER_STATE = [
 class ClusteringOptimizer:
 	def __init__(
 			self, min_k, max_k, n_jobs=-1, keep_models=False, timeout=None,
-			external_parallelization=True, n_external_jobs=None, n_internal_jobs=None, **kwargs
+			external_parallelization=True, **kwargs
 	):
 		self._min_k = min_k
 		self._max_k = max_k
@@ -32,8 +32,6 @@ class ClusteringOptimizer:
 		self._silhouette_scores = None
 		self._timeout = timeout
 		self._external_parallelization = external_parallelization
-		self._n_external_jobs = n_external_jobs
-		self._n_internal_jobs = n_internal_jobs
 
 	def __getstate__(self):
 		return {
@@ -53,9 +51,9 @@ class ClusteringOptimizer:
 		self._inertias = {}
 		self._silhouette_scores = {}
 
-		def get_scores(k, n_jobs):
+		def get_scores(k):
 			kmeans = KMeans(
-				n_clusters=k, n_jobs=n_jobs, timeout=self._timeout, raise_timeout=raise_timeout, **self._kwargs
+				n_clusters=k, timeout=self._timeout, raise_timeout=raise_timeout, **self._kwargs
 			)
 			kmeans.fit(X=X)
 			if kmeans.timedout:
@@ -70,14 +68,12 @@ class ClusteringOptimizer:
 		if self._external_parallelization and self._n_jobs > 1:
 
 			n_ks = self._max_k - self._min_k + 1
-			n_external_jobs = self._n_external_jobs or min(n_ks, self._n_jobs)
-			n_remaining_jobs = self._n_jobs - n_external_jobs
-			n_internal_jobs = self._n_internal_jobs or max(1, int(round(n_remaining_jobs / n_ks)))
-			print(f'n_ks = {n_ks} n_external_jobs = {n_external_jobs} n_internal_jobs = {n_internal_jobs}')
+			n_jobs = min(n_ks, self._n_jobs)
+			print(f'n_ks = {n_ks} n_jobs = {n_jobs}')
 
-			processor = Parallel(n_jobs=n_external_jobs, backend='threading', require='sharedmem')
+			processor = Parallel(n_jobs=n_jobs, backend='threading', require='sharedmem')
 			result = processor(
-				delayed(get_scores)(k=k, n_jobs=n_internal_jobs)
+				delayed(get_scores)(k=k)
 				for k in iterate(iterable=range(self._max_k, self._min_k - 1, -1), echo_items=True, echo=echo)
 			)
 
@@ -100,7 +96,7 @@ class ClusteringOptimizer:
 			for k in range(self._max_k, self._min_k - 1, -1):
 				start_time = get_now()
 				progress_bar.show(amount=self._max_k - k, text=f'j={self._n_jobs}, k={k}{error}, t={round(elapsed)}')
-				k, model, inertia, distortion, silhouette_score = get_scores(k=k, n_jobs=self._n_jobs)
+				k, model, inertia, distortion, silhouette_score = get_scores(k=k)
 				if inertia is not None or distortion is not None or silhouette_score is not None:
 					if self._keep_models:
 						self._models[k] = model
