@@ -4,3 +4,5 @@ from .Polynomial import Polynomial
 from .OneHotEncoder import OneHotEncoder
 from .OneHotEncoder import get_one_hot_encoder_and_encoded
 from .Scaler import Scaler
+from .PCA import PCA
+from .disassemble import disassemble
